==> 1.0.0-dev.2.tar.gz: lib/src/agent/action/null_actions/null_root_action_impl.dart <==
import 'package:tingyun_flutter_plugin/src/agent/action/interface/action.dart';
import 'package:tingyun_flutter_plugin/src/agent/action/interface/root_action.dart';
import 'package:tingyun_flutter_plugin/src/agent/action/null_actions/null_action_impl.dart';

import '../../../../tingyun_flutter_plugin.dart';
import '../null_web_request_timing.dart';

class TingyunNullRootAction implements TingyunRootAction{

  @override
  TingyunAction enterAction(String actionName) {
    return TingyunNullAction();
  }

  @override
  void leaveAction({Map<String, dynamic>props, int type = 0, String tag = ""}) {
    return;
  }

  // @override
  // void reportDoubleValue(String valueName, double value, {Platform platform}) {
  //   return;
  // }
  //
  // @override
  // void reportError(String errorName, int errorCode, {Platform platform}) {
  //   return;
  // }
  //
  // @override
  // void reportEvent(String eventName, {Platform platform}) {
  //   return;
  // }
  //
  // @override
  // void reportIntValue(String valueName, int value, {Platform platform}) {
  //   return;
  // }
  //
  // @override
  // void reportStringValue(String valueName, String value, {Platform platform}) {
  //   return;
  // }

  @override
  Future<String> getRequestTag(String url) async {
    return "";
  }

  @override
  String getRequestTagHeader() {
    return "";
  }

  @override
  Future<TYWebRequestTiming> createWebRequestTiming(String url) {
    return Future.value(NullWebRequestTiming());
  }

  @override
  bool isClosed() {
    return true;
  }

}

==> 2.1.0.tar.gz: lib/src/agent/action/null_actions/null_root_action_impl.dart <==
import 'package:tingyun_flutter_plugin/src/agent/action/interface/action.dart';
import 'package:tingyun_flutter_plugin/src/agent/action/interface/root_action.dart';
import 'package:tingyun_flutter_plugin/src/agent/action/null_actions/null_action_impl.dart';

import '../../../../tingyun_flutter_plugin.dart';
import '../null_web_request_timing.dart';

class TingyunNullRootAction implements TingyunRootAction{

  @override
  TingyunAction enterAction(String actionName) {
    return TingyunNullAction();
  }

  @override
  void leaveAction({Map<String, dynamic>? props, int type = 0, String tag = ""}) {
    return;
  }

  // @override
  // void reportDoubleValue(String valueName, double value, {Platform platform}) {
  //   return;
  // }
  //
  // @override
  // void reportError(String errorName, int errorCode, {Platform platform}) {
  //   return;
  // }
  //
  // @override
  // void reportEvent(String eventName, {Platform platform}) {
  //   return;
  // }
  //
  // @override
  // void reportIntValue(String valueName, int value, {Platform platform}) {
  //   return;
  // }
  //
  // @override
  // void reportStringValue(String valueName, String value, {Platform platform}) {
  //   return;
  // }

  @override
  Future<String> getRequestTag(String url) async {
    return "";
  }

  @override
  String getRequestTagHeader() {
    return "";
  }

  @override
  Future<TYWebRequestTiming> createWebRequestTiming(String url) {
    return Future.value(NullWebRequestTiming());
  }

  @override
  bool isClosed() {
    return true;
  }

}
